@@ -1,4 +1,6 @@
-var RemoteAutocompleteWidget = {
+if (window.yourlabs == undefined) window.yourlabs = {};
+
+yourlabs.RemoteAutocompleteWidget = {
     /*
     The default deck getValue() implementation just returns the PK from the
     choice HTML. RemoteAutocompleteWidget.getValue's implementation checks for
@@ -34,6 +36,6 @@ $(document).bind('yourlabsWidgetReady', function() {
     // Instanciate decks with RemoteAutocompleteWidget as override for all widgets with
     // autocomplete 'remote'.
     $('body').on('initialize', '.autocomplete-light-widget[data-bootstrap=rest_model]', function() {
-        $(this).yourlabsWidget(RemoteAutocompleteWidget);
+        $(this).yourlabsWidget(yourlabs.RemoteAutocompleteWidget);
     });
 });
