@@ -1,10 +1,11 @@
+from __future__ import unicode_literals
+
 from .case import *
 
 from django.contrib.contenttypes.models import ContentType
-from django.contrib.auth.models import Group, Permission
-from django.contrib.auth import get_user_model
-User = get_user_model()
+from django.contrib.auth.models import Permission
 
+from ...example_apps.autocomplete_test_case_app.models import User, Group
 
 
 class AutocompleteGenericMock(autocomplete_light.AutocompleteGenericBase):
@@ -28,9 +29,6 @@ class FormMock(forms.Form):
 class AutocompleteGenericTestCase(AutocompleteTestCase):
     autocomplete_mock = AutocompleteGenericMock
 
-    def setUp(self):
-        self.setUpAuth()
-
     def assert_choices_equal(self, result, test):
         self.assertEqual(list(result), test['expected'])
 
@@ -139,3 +137,9 @@ class AutocompleteGenericTestCase(AutocompleteTestCase):
                 'expected_valid': False,
             },
         )
+
+    def test_default_search_fields(self):
+        class MyGeneric(autocomplete_light.AutocompleteGenericBase):
+            choices = [Group.objects.all()]
+        self.assertEqual(MyGeneric.search_fields, [('name',)])
+
