@@ -4,6 +4,10 @@ An url to AutocompleteView.
 autocomplete_light_autocomplete
     Given a 'autocomplete' argument with the name of the autocomplete, this url
     routes to AutocompleteView.
+
+autocomplete_light_registry
+    Renders the autocomplete registry, good for debugging, requires being
+    authenticated as superuser.
 """
 
 try:
@@ -14,7 +18,7 @@ except ImportError:
 
 from django.views.generic.base import TemplateView
 
-from views import AutocompleteView, RegistryView
+from .views import AutocompleteView, RegistryView
 
 
 urlpatterns = patterns('',
